@@ -49,6 +49,9 @@ describe 'designate::api' do
         is_expected.to contain_designate_config('service:api/enabled_extensions_v2').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_designate_config('service:api/enabled_extensions_admin').with_value('<SERVICE DEFAULT>')
         is_expected.to_not contain_designate__keystone__authtoken('designate_config')
+        is_expected.to contain_oslo__middleware('designate_config').with(
+          :enable_proxy_headers_parsing => '<SERVICE DEFAULT>'
+        )
       end
     end
 
@@ -71,6 +74,7 @@ describe 'designate::api' do
           :pecan_debug                   => true,
           :enabled_extensions_v2         => 'experimental',
           :enabled_extensions_admin      => 'reports,quotas,counts,tenants,target_sync',
+          :enable_proxy_headers_parsing  => true,
         })
       end
 
@@ -91,6 +95,9 @@ describe 'designate::api' do
         is_expected.to contain_designate_config('service:api/pecan_debug').with_value(params[:pecan_debug])
         is_expected.to contain_designate_config('service:api/enabled_extensions_v2').with_value(params[:enabled_extensions_v2])
         is_expected.to contain_designate_config('service:api/enabled_extensions_admin').with_value(params[:enabled_extensions_admin])
+        is_expected.to contain_oslo__middleware('designate_config').with(
+          :enable_proxy_headers_parsing => params[:enable_proxy_headers_parsing]
+        )
       end
     end
 
@@ -109,6 +116,39 @@ describe 'designate::api' do
     end
   end
 
+  shared_examples 'designate-api wsgi' do
+    let :pre_condition do
+      "class { 'designate': }
+       include ::designate::db
+       class { '::designate::keystone::authtoken':
+         password => 'password',
+       }
+       include ::apache
+       "
+    end
+
+    let :params do
+      {
+        :service_name => 'httpd',
+      }
+    end
+
+    context 'with required params' do
+      it { should contain_package('designate-api').with(
+        :ensure => 'present',
+        :name   => platform_params[:api_package_name],
+        :tag    => ['openstack', 'designate-package'],
+      )}
+
+      it { should contain_service('designate-api').with(
+        :ensure => 'stopped',
+        :name   => platform_params[:api_service_name],
+        :enable => false,
+        :tag    => ['designate-service']
+      )}
+    end
+  end
+
   on_supported_os({
     :supported_os => OSDefaults.get_supported_os
   }).each do |os,facts|
@@ -132,6 +172,7 @@ describe 'designate::api' do
         end
       end
       it_behaves_like 'designate-api'
+      it_behaves_like 'designate-api wsgi'
     end
   end
 end
