@@ -28,9 +28,9 @@ describe 'designate::keystone::auth' do
 
       it { is_expected.to contain_keystone_endpoint('RegionOne/designate::dns').with(
         :ensure       => 'present',
-        :public_url   => "http://127.0.0.1:9001/v1",
-        :admin_url    => "http://127.0.0.1:9001/v1",
-        :internal_url => "http://127.0.0.1:9001/v1"
+        :public_url   => "http://127.0.0.1:9001",
+        :admin_url    => "http://127.0.0.1:9001",
+        :internal_url => "http://127.0.0.1:9001"
       ) }
     end
 
@@ -51,30 +51,33 @@ describe 'designate::keystone::auth' do
       ) }
     end
 
-    context 'when overriding auth name' do
+    context 'when overriding auth and service name' do
       let :params do
         { :password => 'foo',
-          :auth_name => 'designate1' }
+          :service_name => 'designatey',
+          :auth_name => 'designatey' }
       end
 
-      it { is_expected.to contain_keystone_user('designate1') }
-      it { is_expected.to contain_keystone_user_role('designate1@services') }
-      it { is_expected.to contain_keystone_service('designate1::dns') }
-      it { is_expected.to contain_keystone_endpoint('RegionOne/designate1::dns') }
+      it { is_expected.to contain_keystone_user('designatey') }
+      it { is_expected.to contain_keystone_user_role('designatey@services') }
+      it { is_expected.to contain_keystone_service('designatey::dns') }
+      it { is_expected.to contain_keystone_endpoint('RegionOne/designatey::dns') }
     end
 
-    context 'when overriding service name' do
-      let :params do
-        { :service_name => 'designate_service',
-          :password => 'foo',
-          :auth_name => 'designate1' }
-      end
+  end
 
-      it { is_expected.to contain_keystone_user('designate1') }
-      it { is_expected.to contain_keystone_user_role('designate1@services') }
-      it { is_expected.to contain_keystone_service('designate_service::dns') }
-      it { is_expected.to contain_keystone_endpoint('RegionOne/designate_service::dns') }
+  describe 'when disabling user and user_role configuration' do
+    let :params do
+      { :configure_user      => false,
+        :configure_user_role => false,
+        :service_name => 'designate',
+        :auth_name => 'designate',
+        :password            => 'designate_password' }
     end
+    it { is_expected.to_not contain_keystone_user('designate') }
+    it { is_expected.to_not contain_keystone_user_role('designate@services') }
+    it { is_expected.to contain_keystone_service('designate::dns') }
+    it { is_expected.to contain_keystone_endpoint('RegionOne/designate::dns') }
   end
 
   on_supported_os({
